@@ -58,35 +58,35 @@
 #include <pyside2_qtcore_python.h>
 
 // Binded library includes
-#include <qsqlquery.h>
-#include <qsqlquerymodel.h>
-#include <qsqltablemodel.h>
-#include <qsqlrelationaltablemodel.h>
 #include <qsqlrecord.h>
-#include <qsqlrelationaldelegate.h>
 #include <qtsqlglobal.h>
-#include <qsqlfield.h>
-#include <qsqldatabase.h>
+#include <qsqlrelationaltablemodel.h>
 #include <qsqldriver.h>
-#include <qsqlresult.h>
+#include <qsqltablemodel.h>
 #include <qsqlindex.h>
+#include <qsqlfield.h>
+#include <qsqlquery.h>
+#include <qsqlrelationaldelegate.h>
 #include <qsqlerror.h>
+#include <qsqldatabase.h>
+#include <qsqlquerymodel.h>
+#include <qsqlresult.h>
 // Conversion Includes - Primitive Types
+#include <QString>
 #include <qabstractitemmodel.h>
 #include <QStringList>
 #include <signalmanager.h>
-#include <QString>
 
 // Conversion Includes - Container Types
-#include <QStack>
+#include <QVector>
+#include <QQueue>
 #include <QList>
 #include <QMultiMap>
-#include <QQueue>
-#include <QLinkedList>
-#include <QVector>
 #include <QSet>
 #include <QPair>
 #include <pysideqflags.h>
+#include <QLinkedList>
+#include <QStack>
 #include <QMap>
 
 // Type indices
@@ -110,11 +110,6 @@
 #define SBK_QSQLQUERY_IDX                                            19
 #define SBK_QSQLQUERY_BATCHEXECUTIONMODE_IDX                         20
 #define SBK_QSQLDRIVERCREATORBASE_IDX                                13
-#define SBK_QSQLQUERYMODEL_IDX                                       21
-#define SBK_QSQLTABLEMODEL_IDX                                       30
-#define SBK_QSQLTABLEMODEL_EDITSTRATEGY_IDX                          31
-#define SBK_QSQLRELATIONALTABLEMODEL_IDX                             25
-#define SBK_QSQLRELATIONALTABLEMODEL_JOINMODE_IDX                    26
 #define SBK_QSQLRELATIONALDELEGATE_IDX                               24
 #define SBK_QSQLDRIVER_IDX                                           7
 #define SBK_QSQLDRIVER_DRIVERFEATURE_IDX                             9
@@ -122,6 +117,11 @@
 #define SBK_QSQLDRIVER_IDENTIFIERTYPE_IDX                            10
 #define SBK_QSQLDRIVER_NOTIFICATIONSOURCE_IDX                        11
 #define SBK_QSQLDRIVER_DBMSTYPE_IDX                                  8
+#define SBK_QSQLQUERYMODEL_IDX                                       21
+#define SBK_QSQLTABLEMODEL_IDX                                       30
+#define SBK_QSQLTABLEMODEL_EDITSTRATEGY_IDX                          31
+#define SBK_QSQLRELATIONALTABLEMODEL_IDX                             25
+#define SBK_QSQLRELATIONALTABLEMODEL_JOINMODE_IDX                    26
 #define SBK_QtSql_IDX_COUNT                                          32
 
 // This variable stores all Python types exported by this module.
@@ -134,9 +134,9 @@ extern SbkConverter** SbkPySide2_QtSqlTypeConverters;
 #define SBK_QTSQL_QVECTOR_QVARIANT_IDX                               0 // QVector<QVariant > &
 #define SBK_QTSQL_QMAP_QSTRING_QVARIANT_IDX                          1 // QMap<QString,QVariant >
 #define SBK_QTSQL_QLIST_QOBJECTPTR_IDX                               2 // const QList<QObject* > &
-#define SBK_QTSQL_QVECTOR_INT_IDX                                    3 // const QVector<int > &
-#define SBK_QTSQL_QHASH_INT_QBYTEARRAY_IDX                           4 // const QHash<int,QByteArray > &
-#define SBK_QTSQL_QLIST_QBYTEARRAY_IDX                               5 // QList<QByteArray >
+#define SBK_QTSQL_QLIST_QBYTEARRAY_IDX                               3 // QList<QByteArray >
+#define SBK_QTSQL_QVECTOR_INT_IDX                                    4 // QVector<int >
+#define SBK_QTSQL_QHASH_INT_QBYTEARRAY_IDX                           5 // const QHash<int,QByteArray > &
 #define SBK_QTSQL_QMAP_INT_QVARIANT_IDX                              6 // QMap<int,QVariant >
 #define SBK_QTSQL_QLIST_QPERSISTENTMODELINDEX_IDX                    7 // const QList<QPersistentModelIndex > &
 #define SBK_QTSQL_QLIST_QVARIANT_IDX                                 8 // QList<QVariant >
@@ -168,11 +168,6 @@ template<> inline PyTypeObject* SbkType< ::QSqlDatabase >() { return reinterpret
 template<> inline PyTypeObject* SbkType< ::QSqlQuery::BatchExecutionMode >() { return SbkPySide2_QtSqlTypes[SBK_QSQLQUERY_BATCHEXECUTIONMODE_IDX]; }
 template<> inline PyTypeObject* SbkType< ::QSqlQuery >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_QtSqlTypes[SBK_QSQLQUERY_IDX]); }
 template<> inline PyTypeObject* SbkType< ::QSqlDriverCreatorBase >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_QtSqlTypes[SBK_QSQLDRIVERCREATORBASE_IDX]); }
-template<> inline PyTypeObject* SbkType< ::QSqlQueryModel >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_QtSqlTypes[SBK_QSQLQUERYMODEL_IDX]); }
-template<> inline PyTypeObject* SbkType< ::QSqlTableModel::EditStrategy >() { return SbkPySide2_QtSqlTypes[SBK_QSQLTABLEMODEL_EDITSTRATEGY_IDX]; }
-template<> inline PyTypeObject* SbkType< ::QSqlTableModel >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_QtSqlTypes[SBK_QSQLTABLEMODEL_IDX]); }
-template<> inline PyTypeObject* SbkType< ::QSqlRelationalTableModel::JoinMode >() { return SbkPySide2_QtSqlTypes[SBK_QSQLRELATIONALTABLEMODEL_JOINMODE_IDX]; }
-template<> inline PyTypeObject* SbkType< ::QSqlRelationalTableModel >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_QtSqlTypes[SBK_QSQLRELATIONALTABLEMODEL_IDX]); }
 template<> inline PyTypeObject* SbkType< ::QSqlRelationalDelegate >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_QtSqlTypes[SBK_QSQLRELATIONALDELEGATE_IDX]); }
 template<> inline PyTypeObject* SbkType< ::QSqlDriver::DriverFeature >() { return SbkPySide2_QtSqlTypes[SBK_QSQLDRIVER_DRIVERFEATURE_IDX]; }
 template<> inline PyTypeObject* SbkType< ::QSqlDriver::StatementType >() { return SbkPySide2_QtSqlTypes[SBK_QSQLDRIVER_STATEMENTTYPE_IDX]; }
@@ -180,6 +175,11 @@ template<> inline PyTypeObject* SbkType< ::QSqlDriver::IdentifierType >() { retu
 template<> inline PyTypeObject* SbkType< ::QSqlDriver::NotificationSource >() { return SbkPySide2_QtSqlTypes[SBK_QSQLDRIVER_NOTIFICATIONSOURCE_IDX]; }
 template<> inline PyTypeObject* SbkType< ::QSqlDriver::DbmsType >() { return SbkPySide2_QtSqlTypes[SBK_QSQLDRIVER_DBMSTYPE_IDX]; }
 template<> inline PyTypeObject* SbkType< ::QSqlDriver >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_QtSqlTypes[SBK_QSQLDRIVER_IDX]); }
+template<> inline PyTypeObject* SbkType< ::QSqlQueryModel >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_QtSqlTypes[SBK_QSQLQUERYMODEL_IDX]); }
+template<> inline PyTypeObject* SbkType< ::QSqlTableModel::EditStrategy >() { return SbkPySide2_QtSqlTypes[SBK_QSQLTABLEMODEL_EDITSTRATEGY_IDX]; }
+template<> inline PyTypeObject* SbkType< ::QSqlTableModel >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_QtSqlTypes[SBK_QSQLTABLEMODEL_IDX]); }
+template<> inline PyTypeObject* SbkType< ::QSqlRelationalTableModel::JoinMode >() { return SbkPySide2_QtSqlTypes[SBK_QSQLRELATIONALTABLEMODEL_JOINMODE_IDX]; }
+template<> inline PyTypeObject* SbkType< ::QSqlRelationalTableModel >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_QtSqlTypes[SBK_QSQLRELATIONALTABLEMODEL_IDX]); }
 
 } // namespace Shiboken
 
